==> haskell-pantry-0.5.7-344-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-pantry.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 pantry
version:              0.5.7
visibility:           public
id:                   pantry-0.5.7-DnlvKT2xuew8OeD6McPjup
key:                  pantry-0.5.7-DnlvKT2xuew8OeD6McPjup
license:              BSD-3-Clause
copyright:            2018-2022 FP Complete
maintainer:           michael@snoyman.com
author:               Michael Snoyman
homepage:             https://github.com/commercialhaskell/pantry#readme
synopsis:             Content addressable Haskell package management
description:
    Please see the README on GitHub at <https://github.com/commercialhaskell/pantry#readme>

category:             Development
abi:                  5f86f6fe65eaff9946d4ce4cc3c96bb8
exposed:              True
exposed-modules:
    Pantry Pantry.Internal Pantry.Internal.AesonExtended
    Pantry.Internal.Companion Pantry.Internal.Stackage
    Pantry.Internal.StaticBytes Pantry.SHA256

hidden-modules:
    Hackage.Security.Client.Repository.HttpLib.HttpClient
    Pantry.Archive Pantry.HTTP Pantry.HPack Pantry.Hackage Pantry.Repo
    Pantry.SQLite Pantry.Storage Pantry.Casa Pantry.Tree Pantry.Types
    System.IsWindows

import-dirs:          /usr/lib/ghc-9.4.8/site-local/pantry-0.5.7
library-dirs:         /usr/lib/ghc-9.4.8/site-local/pantry-0.5.7
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/pantry-0.5.7
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-pantry
hs-libraries:         HSpantry-0.5.7-DnlvKT2xuew8OeD6McPjup
depends:
    Cabal-3.8.1.0 aeson-2.1.2.1-LDBL5bcX1HC79scYyh3opi
    ansi-terminal-1.0.2-6TxOAUbfOQrDbPnWIRhRhS base-4.17.2.1
    bytestring-0.11.5.3 casa-client-0.0.2-G8RcIxXRDtZ5uM0GdOvRgW
    casa-types-0.0.2-GluVDI8PLfNEbgeWNDUFWX
    conduit-1.3.6.1-AL3EmwxQHuQ1mZT9WLAkFR
    conduit-extra-1.3.6-6dO1xP5ViME37M1InDuSps containers-0.6.7
    crypton-0.34-4bqmaNpvFyKLqEcEOMaVvT
    crypton-conduit-0.2.3-FpC7SAL9FKhIIP8nZNhrgs
    digest-0.0.1.7-1ULzTOd58BH2MSqV7QWMT
    filelock-0.1.1.7-1DxbVq27ekEX5jKd8GWNg
    generic-deriving-1.14.5-5DNxvwLHbLx6DXplNQGKHz
    hackage-security-0.6.2.6-DPyzEuIzddbIZ57xeueUZI
    hpack-0.35.2-CxwnDD57OchCAnb7eTltOS
    http-client-0.7.17-39vQCRHDS8Y4AZkwpcxUyW
    http-client-tls-0.3.6.4-8CeCL7zDXbKxhjkugWal5
    http-conduit-2.3.9.1-16gFKEPUkcU7pOEwwzAGYm
    http-download-0.2.1.0-FEfLLivBauJE6WagcRn4td
    http-types-0.12.4-3FyJu2Ux8ftJoanRheHyWI
    memory-0.18.0-1oHOZXUPjWrG0kImkORGvt mtl-2.2.2
    network-uri-2.6.4.2-EjZpKZ4F93eKYvVi9AsGV0
    path-0.9.5-KRJL3QivdtmAcOuXjSrMOP
    path-io-1.8.2-4LpMJDpAI08DA4Z36PCl6T
    persistent-2.14.5.1-8EJR1PSgMGR4lER4baVil7
    persistent-sqlite-2.13.1.0-5Gv8u1OQawLBBf9CyAd2PW
    primitive-0.8.0.0-KvNzOAcw1vIIZ8l6YzsRlk
    resourcet-1.2.6-BEi0OW4T0Qo1xg4KkAo7Sv
    rio-0.1.22.0-7Tj8jsrWq1OLsTY4yONzBW
    rio-orphans-0.1.2.0-26RU6j3pcss3iyaKAY98e4
    rio-prettyprint-0.1.7.0-1ZOv5WXsoIx3iQmTPkNOxj
    tar-conduit-0.4.1-13cXxZ4q50P2tD5heIDOsy text-2.0.2
    text-metrics-0.3.2-7LbYw4e2Fb6FahL2c7YcG time-1.12.2
    transformers-0.5.6.2 unix-compat-0.7.3-FZLvposRpy5EPSL1bbufv9
    unliftio-0.2.25.1-vpTZzYd6tBQ0TaDZjKjs
    unordered-containers-0.2.20-2kG5VEC3Gy42AwINT9WJ9w
    vector-0.13.1.0-Dc65CzydytHE52tdajtbOv
    yaml-0.11.11.2-7NEgW6E2pbYEs4sf4NTDIA
    zip-archive-0.4.3.2-6nIaUJl3KFJ6ElRifzhA9q

haddock-interfaces:   /usr/share/doc/haskell-pantry/html/pantry.haddock
haddock-html:         /usr/share/doc/haskell-pantry/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-pantry-0.5.7-345-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-pantry.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 pantry
version:              0.5.7
visibility:           public
id:                   pantry-0.5.7-JzYemVxE8Ni2ARufp3uGtQ
key:                  pantry-0.5.7-JzYemVxE8Ni2ARufp3uGtQ
license:              BSD-3-Clause
copyright:            2018-2022 FP Complete
maintainer:           michael@snoyman.com
author:               Michael Snoyman
homepage:             https://github.com/commercialhaskell/pantry#readme
synopsis:             Content addressable Haskell package management
description:
    Please see the README on GitHub at <https://github.com/commercialhaskell/pantry#readme>

category:             Development
abi:                  e36fbdcc48a06a9d7e274a7ed7db6a12
exposed:              True
exposed-modules:
    Pantry Pantry.Internal Pantry.Internal.AesonExtended
    Pantry.Internal.Companion Pantry.Internal.Stackage
    Pantry.Internal.StaticBytes Pantry.SHA256

hidden-modules:
    Hackage.Security.Client.Repository.HttpLib.HttpClient
    Pantry.Archive Pantry.HTTP Pantry.HPack Pantry.Hackage Pantry.Repo
    Pantry.SQLite Pantry.Storage Pantry.Casa Pantry.Tree Pantry.Types
    System.IsWindows

import-dirs:          /usr/lib/ghc-9.4.8/site-local/pantry-0.5.7
library-dirs:         /usr/lib/ghc-9.4.8/site-local/pantry-0.5.7
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/pantry-0.5.7
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-pantry
hs-libraries:         HSpantry-0.5.7-JzYemVxE8Ni2ARufp3uGtQ
depends:
    Cabal-3.8.1.0 aeson-2.1.2.1-LDBL5bcX1HC79scYyh3opi
    ansi-terminal-1.0.2-6TxOAUbfOQrDbPnWIRhRhS base-4.17.2.1
    bytestring-0.11.5.3 casa-client-0.0.2-G8RcIxXRDtZ5uM0GdOvRgW
    casa-types-0.0.2-GluVDI8PLfNEbgeWNDUFWX
    conduit-1.3.6.1-AL3EmwxQHuQ1mZT9WLAkFR
    conduit-extra-1.3.6-6dO1xP5ViME37M1InDuSps containers-0.6.7
    crypton-0.34-4bqmaNpvFyKLqEcEOMaVvT
    crypton-conduit-0.2.3-FpC7SAL9FKhIIP8nZNhrgs
    digest-0.0.1.7-1ULzTOd58BH2MSqV7QWMT
    filelock-0.1.1.7-1DxbVq27ekEX5jKd8GWNg
    generic-deriving-1.14.5-5DNxvwLHbLx6DXplNQGKHz
    hackage-security-0.6.2.6-DPyzEuIzddbIZ57xeueUZI
    hpack-0.35.2-CxwnDD57OchCAnb7eTltOS
    http-client-0.7.17-39vQCRHDS8Y4AZkwpcxUyW
    http-client-tls-0.3.6.4-8CeCL7zDXbKxhjkugWal5
    http-conduit-2.3.9.1-16gFKEPUkcU7pOEwwzAGYm
    http-download-0.2.1.0-FEfLLivBauJE6WagcRn4td
    http-types-0.12.4-3FyJu2Ux8ftJoanRheHyWI
    memory-0.18.0-1oHOZXUPjWrG0kImkORGvt mtl-2.2.2
    network-uri-2.6.4.2-EjZpKZ4F93eKYvVi9AsGV0
    path-0.9.5-KRJL3QivdtmAcOuXjSrMOP
    path-io-1.8.2-4LpMJDpAI08DA4Z36PCl6T
    persistent-2.14.5.1-8EJR1PSgMGR4lER4baVil7
    persistent-sqlite-2.13.1.0-LveFpV2jt1nA4LIXGUTFFk
    primitive-0.8.0.0-KvNzOAcw1vIIZ8l6YzsRlk
    resourcet-1.2.6-BEi0OW4T0Qo1xg4KkAo7Sv
    rio-0.1.22.0-7Tj8jsrWq1OLsTY4yONzBW
    rio-orphans-0.1.2.0-26RU6j3pcss3iyaKAY98e4
    rio-prettyprint-0.1.7.0-1ZOv5WXsoIx3iQmTPkNOxj
    tar-conduit-0.4.1-13cXxZ4q50P2tD5heIDOsy text-2.0.2
    text-metrics-0.3.2-7LbYw4e2Fb6FahL2c7YcG time-1.12.2
    transformers-0.5.6.2 unix-compat-0.7.3-FZLvposRpy5EPSL1bbufv9
    unliftio-0.2.25.1-vpTZzYd6tBQ0TaDZjKjs
    unordered-containers-0.2.20-2kG5VEC3Gy42AwINT9WJ9w
    vector-0.13.1.0-Dc65CzydytHE52tdajtbOv
    yaml-0.11.11.2-7NEgW6E2pbYEs4sf4NTDIA
    zip-archive-0.4.3.2-6nIaUJl3KFJ6ElRifzhA9q

haddock-interfaces:   /usr/share/doc/haskell-pantry/html/pantry.haddock
haddock-html:         /usr/share/doc/haskell-pantry/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
